import { AddPizzaRequest, FinishDeliveryRequest, PizzaOrder, RemovePizzaRequest, UpdatePizzaDayNoteRequest, UpdatePizzaFeeRequest } from "../../../types";
import { api } from "./Api";

const PIZZADAY_API_PREFIX = '/api/pizzaDay';

export const createPizzaDay = async () => {
    return await api.post<undefined, void>(`${PIZZADAY_API_PREFIX}/create`);
}

export const deletePizzaDay = async () => {
    return await api.post<undefined, void>(`${PIZZADAY_API_PREFIX}/delete`);
}

export const lockPizzaDay = async () => {
    return await api.post<undefined, void>(`${PIZZADAY_API_PREFIX}/lock`);
}

export const unlockPizzaDay = async () => {
    return await api.post<undefined, void>(`${PIZZADAY_API_PREFIX}/unlock`);
}

export const finishOrder = async () => {
    return await api.post<undefined, void>(`${PIZZADAY_API_PREFIX}/finishOrder`);
}

export const finishDelivery = async (bankAccount?: string, bankAccountHolder?: string) => {
    return await api.post<FinishDeliveryRequest, void>(`${PIZZADAY_API_PREFIX}/finishDelivery`, { bankAccount, bankAccountHolder });
}

export const addPizza = async (pizzaIndex: number, pizzaSizeIndex: number) => {
    return await api.post<AddPizzaRequest, void>(`${PIZZADAY_API_PREFIX}/add`, { pizzaIndex, pizzaSizeIndex });
}

export const removePizza = async (pizzaOrder: PizzaOrder) => {
    return await api.post<RemovePizzaRequest, void>(`${PIZZADAY_API_PREFIX}/remove`, { pizzaOrder });
}

export const updatePizzaDayNote = async (note?: string) => {
    return await api.post<UpdatePizzaDayNoteRequest, void>(`${PIZZADAY_API_PREFIX}/updatePizzaDayNote`, { note });
}

export const updatePizzaFee = async (login: string, text?: string, price?: number) => {
    return await api.post<UpdatePizzaFeeRequest, void>(`${PIZZADAY_API_PREFIX}/updatePizzaFee`, { login, text, price });
}
